==> onos-yang-runtime-2.2.0-b5-sources.jar: org/onosproject/yang/gen/v1/ytbmodulewithlist/rev20160826/YtbModuleWithListOpParam.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ytbmodulewithlist.rev20160826;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ytbmodulewithlist.rev20160826.ytbmodulewithlist.Ytblistlist;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of ytbModuleWithList.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class YtbModuleWithListOpParam extends InnerModelObject implements YtbModuleWithList {
    protected List<Ytblistlist> ytblistlist;

    @Override
    public List<Ytblistlist> ytblistlist() {
        return ytblistlist;
    }

    @Override
    public void ytblistlist(List<Ytblistlist> ytblistlist) {
        this.ytblistlist = ytblistlist;
    }

    @Override
    public void addToYtblistlist(Ytblistlist addTo) {
        if (ytblistlist == null) {
            ytblistlist = new ArrayList<>();
        }
        ytblistlist.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(ytblistlist);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof YtbModuleWithListOpParam) {
            YtbModuleWithListOpParam other = (YtbModuleWithListOpParam) obj;
            return
                Objects.equals(ytblistlist, other.ytblistlist);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("ytblistlist=" + ytblistlist)
            .toString();
    }

    /**
     * Creates an instance of ytbModuleWithListOpParam.
     */
    public YtbModuleWithListOpParam() {
    }


    @Override
    public void addAugmentation(InnerModelObject obj) {
    }

    @Override
    public void removeAugmentation(InnerModelObject obj) {
    }

    @Override
    public Map<Class<? extends InnerModelObject>, InnerModelObject> augmentations() {

        return null;
    }

    @Override
    public <T extends InnerModelObject> T augmentation(Class<T> c) {

        return null;
    }
}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ytbmodulewithlist/rev20160826/YtbModuleWithListOpParam.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ytbmodulewithlist.rev20160826;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ytbmodulewithlist.rev20160826.ytbmodulewithlist.Ytblistlist;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of ytbModuleWithList.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class YtbModuleWithListOpParam extends InnerModelObject implements YtbModuleWithList {
    protected List<Ytblistlist> ytblistlist;

    @Override
    public List<Ytblistlist> ytblistlist() {
        return ytblistlist;
    }

    @Override
    public void ytblistlist(List<Ytblistlist> ytblistlist) {
        this.ytblistlist = ytblistlist;
    }

    @Override
    public void addToYtblistlist(Ytblistlist addTo) {
        if (ytblistlist == null) {
            ytblistlist = new ArrayList<>();
        }
        ytblistlist.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(ytblistlist);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof YtbModuleWithListOpParam) {
            YtbModuleWithListOpParam other = (YtbModuleWithListOpParam) obj;
            return
                Objects.deepEquals(ytblistlist, other.ytblistlist);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("ytblistlist=" + ytblistlist)
            .toString();
    }

    /**
     * Creates an instance of ytbModuleWithListOpParam.
     */
    public YtbModuleWithListOpParam() {
    }


    @Override
    public void addAugmentation(InnerModelObject obj) {
    }

    @Override
    public void removeAugmentation(InnerModelObject obj) {
    }

    @Override
    public Map<Class<? extends InnerModelObject>, InnerModelObject> augmentations() {

        return null;
    }

    @Override
    public <T extends InnerModelObject> T augmentation(Class<T> c) {

        return null;
    }
}
